@@ -133,6 +133,8 @@ departments = {
             "Jardín":{"dane_code":"05364"},
             "Sonsón":{"dane_code":"05756"},
             "Belmira":{"dane_code":"05086"},
+            "San Pedro":{"dane_code":"05664"},
+            "San Pedro de los milagros":{"dane_code":"05664"},
             "San Pedro de Uraba":{"dane_code":"05665"},
             "Santafé de Antioquia":{"dane_code":"05042"},
             "Santa Rosa de Osos":{"dane_code":"05686"},
@@ -1257,5 +1259,14 @@ departments = {
             "Santa Rosalía":{"dane_code":"99624"},
             "Cumaribo":{"dane_code":"99773"},
         }
+    },
+    "San Andrés, Providencia y Santa Catalina":{
+        "dane_code":"88",
+        "municipalities":{
+            "Providencia Y Santa Catalina":{"dane_code":"88564"},
+            "Providencia":{"dane_code":"88564"},
+            "Santa Catalina":{"dane_code":"88564"},
+            "San Andres":{"dane_code":"88001"},
+        }
     }
 }
\ No newline at end of file
